#ifndef NASM_WARNINGS_H
#define NASM_WARNINGS_H

#ifndef WARN_SHR
# error "warnings.h should only be included from within error.h"
#endif

enum warn_index {
	WARN_IDX_NONE                    =   0, /* not suppressible */
	WARN_IDX_BAD_PRAGMA              =   1, /* empty or malformed %pragma */
	WARN_IDX_BND                     =   2, /* invalid BND prefixes */
	WARN_IDX_FLOAT_DENORM            =   3, /* floating point denormal */
	WARN_IDX_FLOAT_OVERFLOW          =   4, /* floating point overflow */
	WARN_IDX_FLOAT_TOOLONG           =   5, /* too many digits in floating-point number */
	WARN_IDX_FLOAT_UNDERFLOW         =   6, /* floating point underflow */
	WARN_IDX_GNU_ELF_EXTENSIONS      =   7, /* using 8- or 16-bit relocation in ELF32, a GNU extension */
	WARN_IDX_HLE                     =   8, /* invalid HLE prefixes */
	WARN_IDX_LABEL_REDEF             =   9, /* label redefined to an identical value */
	WARN_IDX_LABEL_REDEF_LATE        =  10, /* label (re)defined during code generation */
	WARN_IDX_LOCK                    =  11, /* LOCK prefix on unlockable instructions */
	WARN_IDX_MACRO_DEFAULTS          =  12, /* macros with more default than optional parameters */
	WARN_IDX_MACRO_PARAMS            =  13, /* macro calls with wrong parameter count */
	WARN_IDX_NEGATIVE_REP            =  14, /* regative %rep count */
	WARN_IDX_NOT_MY_PRAGMA           =  15, /* %pragma not applicable to this compilation */
	WARN_IDX_NUMBER_OVERFLOW         =  16, /* numeric constant does not fit */
	WARN_IDX_ORPHAN_LABELS           =  17, /* labels alone on lines without trailing `:' */
	WARN_IDX_PHASE                   =  18, /* phase error during stabilization */
	WARN_IDX_PTR                     =  19, /* non-NASM keyword used in other assemblers */
	WARN_IDX_UNKNOWN_PRAGMA          =  20, /* unknown %pragma facility or directive */
	WARN_IDX_UNKNOWN_WARNING         =  21, /* unknown warning in -W/-w or warning directive */
	WARN_IDX_USER                    =  22, /* %warning directives */
	WARN_IDX_WARN_STACK_EMPTY        =  23, /* warning stack empty */
	WARN_IDX_ZEROING                 =  24, /* RESx in initialized section becomes zero */
	WARN_IDX_ZEXT_RELOC              =  25, /* relocation zero-extended to match output format */
	WARN_IDX_OTHER                   =  26, /* any warning not specifially mentioned above */
	WARN_IDX_ALL                     =  27  /* all possible warnings */
};

enum warn_const {
	WARN_NONE                        =   0 << WARN_SHR,
	WARN_BAD_PRAGMA                  =   1 << WARN_SHR,
	WARN_BND                         =   2 << WARN_SHR,
	WARN_FLOAT_DENORM                =   3 << WARN_SHR,
	WARN_FLOAT_OVERFLOW              =   4 << WARN_SHR,
	WARN_FLOAT_TOOLONG               =   5 << WARN_SHR,
	WARN_FLOAT_UNDERFLOW             =   6 << WARN_SHR,
	WARN_GNU_ELF_EXTENSIONS          =   7 << WARN_SHR,
	WARN_HLE                         =   8 << WARN_SHR,
	WARN_LABEL_REDEF                 =   9 << WARN_SHR,
	WARN_LABEL_REDEF_LATE            =  10 << WARN_SHR,
	WARN_LOCK                        =  11 << WARN_SHR,
	WARN_MACRO_DEFAULTS              =  12 << WARN_SHR,
	WARN_MACRO_PARAMS                =  13 << WARN_SHR,
	WARN_NEGATIVE_REP                =  14 << WARN_SHR,
	WARN_NOT_MY_PRAGMA               =  15 << WARN_SHR,
	WARN_NUMBER_OVERFLOW             =  16 << WARN_SHR,
	WARN_ORPHAN_LABELS               =  17 << WARN_SHR,
	WARN_PHASE                       =  18 << WARN_SHR,
	WARN_PTR                         =  19 << WARN_SHR,
	WARN_UNKNOWN_PRAGMA              =  20 << WARN_SHR,
	WARN_UNKNOWN_WARNING             =  21 << WARN_SHR,
	WARN_USER                        =  22 << WARN_SHR,
	WARN_WARN_STACK_EMPTY            =  23 << WARN_SHR,
	WARN_ZEROING                     =  24 << WARN_SHR,
	WARN_ZEXT_RELOC                  =  25 << WARN_SHR,
	WARN_OTHER                       =  26 << WARN_SHR
};

extern const char * const warning_name[28];
extern const char * const warning_help[28];
extern const uint8_t warning_default[27];
extern uint8_t warning_state[27];

#endif /* NASM_WARNINGS_H */
